@@ -23,12 +23,18 @@
 //! # Ok::<(), io::Error>(())
 //! ```
 
+#[cfg(feature = "async")]
+pub mod r#async;
+
 pub mod index;
 mod reader;
 mod writer;
 
 pub use self::{index::Index, reader::Reader, writer::Writer};
 
+#[cfg(feature = "async")]
+pub use self::r#async::{Reader as AsyncReader, Writer as AsyncWriter};
+
 use std::{fs::File, io, path::Path};
 
 use self::index::reference_sequence::Bin;
