@@ -84,8 +84,8 @@ where
     ///
     /// The position of the stream is expected to be at the start.
     ///
-    /// This returns the raw SAM header as a [`std::string::String`]. It can subsequently be parsed
-    /// as a [`noodles_sam::Header`].
+    /// This returns the raw SAM header as a [`String`]. It can subsequently be parsed as a
+    /// [`noodles_sam::Header`].
     ///
     /// # Examples
     ///
@@ -284,7 +284,7 @@ where
     /// let reference_sequences = header.reference_sequences();
     /// let index = bai::read("sample.bam.bai")?;
     /// let region = Region::mapped("sq0", 17711..=28657);
-    /// let query = reader.query(&reference_sequences, &index, &region)?;
+    /// let query = reader.query(reference_sequences, &index, &region)?;
     ///
     /// for result in query {
     ///     let record = result?;
@@ -382,7 +382,7 @@ where
     ReferenceSequence::new(name, l_ref).map_err(|e| io::Error::new(io::ErrorKind::InvalidData, e))
 }
 
-fn bytes_with_nul_to_string(buf: &[u8]) -> io::Result<String> {
+pub(crate) fn bytes_with_nul_to_string(buf: &[u8]) -> io::Result<String> {
     CStr::from_bytes_with_nul(buf)
         .map_err(|e| io::Error::new(io::ErrorKind::InvalidData, e))
         .and_then(|c_str| {
@@ -393,7 +393,7 @@ fn bytes_with_nul_to_string(buf: &[u8]) -> io::Result<String> {
         })
 }
 
-fn resolve_region(
+pub(crate) fn resolve_region(
     reference_sequences: &ReferenceSequences,
     region: &Region,
 ) -> io::Result<(usize, Interval)> {
