@@ -154,7 +154,7 @@ where
         self.inner.write_i32::<LittleEndian>(n_ref)?;
 
         for reference_sequence in reference_sequences.values() {
-            write_reference(&mut self.inner, reference_sequence)?;
+            write_reference_sequence(&mut self.inner, reference_sequence)?;
         }
 
         Ok(())
@@ -204,7 +204,10 @@ where
     }
 }
 
-fn write_reference<W>(writer: &mut W, reference_sequence: &ReferenceSequence) -> io::Result<()>
+fn write_reference_sequence<W>(
+    writer: &mut W,
+    reference_sequence: &ReferenceSequence,
+) -> io::Result<()>
 where
     W: Write,
 {
@@ -456,4 +459,21 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn test_write_reference_sequence() -> Result<(), Box<dyn std::error::Error>> {
+        let mut buf = Vec::new();
+        let reference_sequence = ReferenceSequence::new("sq0", 8)?;
+        write_reference_sequence(&mut buf, &reference_sequence)?;
+
+        let expected = [
+            0x04, 0x00, 0x00, 0x00, // l_name = 4
+            0x73, 0x71, 0x30, 0x00, // name = b"sq0\x00"
+            0x08, 0x00, 0x00, 0x00, // l_ref = 8
+        ];
+
+        assert_eq!(buf, expected);
+
+        Ok(())
+    }
 }
